View source: R/cf_downscale_hv.R
| cf_downscale_hv | R Documentation |
Trains the CF-DS model and selects the number of spatial scales through sequential holdout validation.
cf_downscale_hv(
Y,
Y_type = "sum",
x = NULL,
prop_weight = NULL,
coords,
agg_id,
train_rat = 0.75,
id_train = NULL,
alpha = 0.9,
kernel = "exp",
rel_tol = 1e-04,
seed = 123
)
Y |
Vector of aggregate-level response values (length |
Y_type |
Aggregation type of |
x |
Matrix of disaggregate-level covariates ( |
prop_weight |
Vector of disaggregate-level proportional allocation
weights (length |
coords |
Matrix of disaggregate-level coordinates ( |
agg_id |
Area ID for each disaggregate-level unit (length |
train_rat |
Ratio of the aggregate-level units used for model training (default 0.75) in the holdout validation. |
id_train |
Optional. If specified, the corresponding aggregate-level units are used as training units. Otherwise, training units are chosen based on 'train_rat'. |
alpha |
Decay ratio of the kernel bandwidth in the coarse-to-fine training (default: 0.9). Values closer to one make the optimization more stringent but increase computation time. |
kernel |
Kernel type for modeling spatial dependence. '"exp"' for the exponential kernel (default) and '"gau"' for the Gaussian kernel. |
rel_tol |
Relative improvement threshold for validation SSE
(default |
seed |
Random seed used for the training/validation split when 'id_train' is not supplied. Default is '123'. Set to 'NULL' to allow a different split at each call (useful for assessing split sensitivity). |
A list with the following elements:
Final sum-of-squared error (SSE) for validation samples.
SSEs obtained at each learning step.
ID of training aggregate-level units.
Other internally used output objects.
Daisuke Murakami
Murakami, D., Chun, Y., Yoshida, T., & Seya, H. (2026). Scalable coarse-to-fine spatial downscaling. *ArXiv preprint*, 2606.29798.
cf_downscale, cf_lm_hv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.