Evaluate mean and variance of the spatial process with bandwidth values within a pre-specified range
sp_scalewise(mod, bw_range = c(0, Inf))A list with the following elements:
Means and standard deviations of the spatial process (sample sites).
Means and standard deviations of the spatial process (prediction sites).
Output object from the cf_lm function.
Range of bandwidth values of the simulated spatial processes. For example, if bw_range = c(10, 20), spatial processes with bandwidths between 10 and 20 are synthesized and simulated. The default is c(0, Inf), which synthesizes all scales.
Daisuke Murakami
cf_lm